/***********************************************************
 * $Id: FlatRemoteException.java 83 2009-07-20 20:35:55Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 20.07.2009
 * 
 ***********************************************************/

package org.clazzes.remoting;

/**
 * This exception is used in order to serialize an exception not
 * otherwise serializable.
 * 
 * @author wglas
 */
public class FlatRemoteException extends RuntimeException {

    private static final long serialVersionUID = -7831517399321247574L;
    private String originalClassName;
    
    public FlatRemoteException() {
    }

    public FlatRemoteException(String originalClassName) {
        this.originalClassName = originalClassName;
    }

    public FlatRemoteException(String originalClassName, String message) {
        super(message);
        this.originalClassName = originalClassName;
    }

    public FlatRemoteException(String originalClassName, Throwable cause) {
        super(cause);
        this.originalClassName = originalClassName;
    }

    public FlatRemoteException(String originalClassName, String message, Throwable cause) {
        super(message, cause);
        this.originalClassName = originalClassName;
    }

    public FlatRemoteException(Throwable original) {
        super(original.getMessage(),original.getCause());
        super.setStackTrace(original.getStackTrace());
        this.originalClassName = original.getClass().getName();
    }
    
    /**
     * @return the class name of the original exception.
     */
    public String getOriginalClassName() {
        return this.originalClassName;
    }

    /**
     * @param originalClassName the original class name to set.
     */
    public void setOriginalClassName(String originalClassName) {
        this.originalClassName = originalClassName;
    }
}
