/***********************************************************
 * $Id: InvocationHandler.java 89 2009-07-27 13:25:05Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 14.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting;

import java.lang.reflect.InvocationTargetException;
import java.util.Map;

/**
 * An invocation handler, which is registered under a subsystem name at a server.
 * or handles callbacks on a client.
 * 
 * @author wglas
 */
public interface InvocationHandler {

    /**
     * @param ctx The context under which the call has been issued.
     * @param arg The argument of the call.
     * @param metadata The metadata accompanying the remote call, which is passed to the
     *                 invocation handler. Metadata may be used to communicate authorization
     *                 information such as user/password or a session Id.
     * @return The result of the operation.
     * 
     * @throws Throwable Any exception raised by the call. This exception will be reported
     *             back to the invoker as the root cause of an {@link InvocationTargetException}.
     */
    public Object invoke (InvocationContext ctx, Object arg, Map<String,Object> metadata) throws Throwable;

}
