/***********************************************************
 * $Id: BeanCallAuthManager.java 66 2009-04-30 13:47:14Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 29.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.beans;

import java.lang.reflect.Method;
import java.rmi.server.UID;
import java.util.Map;

import org.clazzes.remoting.RemoteInvocation;
import org.clazzes.remoting.client.Client;

/**
 * An implementation of this interface manages the authentication of
 * remote calls. This interface might be combined with the {@link SessionManager}
 * interface in order to authenticate against a pre-authenticated session.
 * 
 * @author wglas
 */
public interface BeanCallAuthManager {

	/**
	 * Authenticate a remote call.
	 * 
	 * @param ri The remote invocation to authenticate.
	 * @param method The local method to invoke. This might be used to search for
	 *               application-specific authentication annotations.
	 * @param sessionId The session ID as returned by {@link Client#getClientUID()}.
	 * @param metadata The request metadata.
	 * @throws SecurityException Upon authentication errors.
	 */
	public void authenticate(RemoteInvocation ri, Method method,
	                         UID sessionId, Map<String,Object> metadata) throws SecurityException;
}
