/***********************************************************
 * $Id: ClientHolder.java 68 2009-05-02 21:23:05Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 29.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.beans;

import org.clazzes.remoting.client.Client;

/**
 * This interface is implemented by thread-bound session contexts, which bind
 * a resource to a specific client.
 * 
 * @author wglas
 */
public class ClientHolder {

    private static ThreadLocal<ClientHolder> context = new ThreadLocal<ClientHolder>();
    
    /**
     * @param holder The current client holder to attach to the current thread.
     */
    public static void setContext(ClientHolder holder) {
        
        context.set(holder);
    }
    
    /**
     * @return The client holder attached to the current thread
     *          using {@link #setContext(ClientHolder)}.
     */
    public static ClientHolder getContext() {
        
        return context.get();
    }
    
    /**
     * Remove the client holder attached to the current thread. 
     */
    public static void removeContext() {
        
        context.remove();
    }
    
    private final Client client;
    private boolean closeOnPassivate;
    
    public ClientHolder(Client client) {
        
        this.client = client;
        this.closeOnPassivate = false;
    }
    
	/**
	 * @return The client to which the thread-bound context belongs.
	 */
    public Client getClient() {
        return this.client;
    }
	
	/**
	 * @param closeOnPassivate Whether to close this stream before passivating
	 *                        because of an I/O error.
	 */
	public void setCloseOnPassivate(boolean closeOnPassivate) {
	    this.closeOnPassivate = closeOnPassivate;
    }
	
	/**
	 * @return Whether to close this stream before passivating
	 *                       because of an I/O error.
	 */
	public boolean isCloseOnPassivate() {
        return this.closeOnPassivate;
    }	
	
}
