/***********************************************************
 * $Id: ClientManager.java 18 2008-10-18 19:24:13Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 18.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting.client;

import java.io.IOException;
import java.util.concurrent.TimeoutException;

import javax.security.auth.Destroyable;

/**
 * An interface, which is implemented by bean who are accounting client
 * connections to a server.
 * 
 * @author wglas
 */
public interface ClientManager extends Destroyable {

    /**
     * Start the client pool after setting a relevant properties.
     * 
     * @throws IOException Upon connection errors.
     */
    public abstract void start() throws IOException;

    /**
     * @return A client pulled from the pool.
     * @throws TimeoutException Upon connection errors or when the pool
     *            has no more clients available within a given timeout.
     */
    public abstract Client activateClient() throws TimeoutException;

    /**
     * @param client A client which previously has been pulled
     *         from the pool using {@link #activateClient()} and may
     *         now be used by other consumers.
     */
    public abstract void passivateClient(Client client);

}