/***********************************************************
 * $Id: InetAddressHelper.java 9 2008-10-17 14:43:25Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting.helper;

import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.util.Random;

/**
 * A class, which helps to resolve InetSocketAddress objects
 * in a round-robin fashion.
 * 
 * @author wglas
 */
public abstract class InetAddressHelper {

    static Random random;
    
    static private synchronized int getRandomIndex(int n) {
        
        if (random == null)
            random = new Random();
        
        return random.nextInt(n);
    }
    
    public static InetSocketAddress resolveSocketAddress(InetSocketAddress addr) throws IOException {
        
        if (addr.isUnresolved()) {
 
            InetAddress[] ipAddrs = InetAddress.getAllByName(addr.getHostName());
            
            if (ipAddrs.length < 1)
                throw new IOException("Host name ["+addr.getHostName()+"] could not be resolved.");
            
            int idx = ipAddrs.length == 1 ? 0 : getRandomIndex(ipAddrs.length);
            
            return  new InetSocketAddress(ipAddrs[idx],addr.getPort());
        }
        else
            return addr;
    }
}
