/***********************************************************
 * $Id: LoadingObjectInputStream.java 140 2009-10-01 14:38:03Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 01.10.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.loading;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;
import java.lang.reflect.Proxy;

/**
 * An object input stream with an underlying ClassLoader.
 */
public class LoadingObjectInputStream extends ObjectInputStream {

    private final ClassLoader classLoader;
    
    /**
     * @param in The input stream to read from.
     * @param cl The class loader to resolve classes from the stream.
     * @throws IOException
     */
    public LoadingObjectInputStream(InputStream in, ClassLoader cl) throws IOException {
        super(in);
        this.classLoader = cl;
    }

    /**
     * @return The ClassLoader used for deserialization.
     */
    public ClassLoader getClassLoader() {
        return this.classLoader;
    }

    /* (non-Javadoc)
     * @see java.io.ObjectInputStream#resolveClass(java.io.ObjectStreamClass)
     */
    @Override
    protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException,
            ClassNotFoundException {
        
        if (this.classLoader == null)
            return super.resolveClass(desc);
        
        return Class.forName(desc.getName(),false,this.classLoader);
    }

    /* (non-Javadoc)
     * @see java.io.ObjectInputStream#resolveProxyClass(java.lang.String[])
     */
    @Override
    protected Class<?> resolveProxyClass(String[] interfaces)
            throws IOException, ClassNotFoundException {
        
        if (this.classLoader == null)
            return super.resolveProxyClass(interfaces);
        
        Class<?> resolvedIfaces[] = new Class<?>[interfaces.length];
        
        for (int i=0;i<interfaces.length; ++i) {
            
            resolvedIfaces[i]=Class.forName(interfaces[i],false,this.classLoader);
        }
        
        return Proxy.getProxyClass(this.classLoader,resolvedIfaces);
    }

    
    
}
