/***********************************************************
 * $Id: MarshalerFactorySupport.java 62 2009-04-25 20:41:38Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 25.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal;

/**
 * A support class for the most common factory options.
 * 
 * @author wglas
 */
public abstract class MarshalerFactorySupport implements MarshalerFactory {

    private int outputBufferSize;
    private int inputBufferSize;

    /**
     * Instantiate a DefaultMarsalerFactory with the input and output buffer size
     * set to <code>1460</code>, the most common MSS for TCP over ethernet.
     * 
     */
    public MarshalerFactorySupport() {
        super();
        this.outputBufferSize = 1460;
        this.inputBufferSize = 1460;
    }

    public abstract Marshaler newMarshaler();

    /**
     * @return The output buffer size to use for the generated {@link JAVAMarshaler} instances.
     */
    public int getOutputBufferSize() {
        return this.outputBufferSize;
    }

    /**
     * @param outputBufferSize The output buffer size to set.
     */
    public void setOutputBufferSize(int outputBufferSize) {
        this.outputBufferSize = outputBufferSize;
    }

    /**
     * @return The input buffer size to use for the generated {@link JAVAMarshaler} instances.
     */
    public int getInputBufferSize() {
        return this.inputBufferSize;
    }

    /**
     * @param inputBufferSize The input buffer size to set.
     */
    public void setInputBufferSize(int inputBufferSize) {
        this.inputBufferSize = inputBufferSize;
    }

}