/***********************************************************
 * $Id: ClassInfo.java 73 2009-05-25 19:24:51Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;

/**
 * @author wglas
 *
 */
public class ClassInfo {

    private static long fetchSerialVerionUID(Class<?> clazz) {
        
        try {
            
            Field sv = clazz.getDeclaredField("serialVersionUID");
            
            sv.setAccessible(true);
            
            if (Modifier.isStatic(sv.getModifiers()) &&
                    Modifier.isFinal(sv.getModifiers()))
                return ((Long)sv.get(null)).longValue();
            
        } catch (NoSuchFieldException e) {
           
        } catch (Throwable e) {
            throw new RuntimeException("Cannot fetch serialVersionUID of ["+clazz+"]",e);
        }
        
        return -1L;
    }

    private final String clazz;
    private final long serialVersionUID;
    
    public ClassInfo(String clazz, long serialVersionUID) {
        super();
        this.clazz = clazz;
        this.serialVersionUID = serialVersionUID;
    }
    
    public ClassInfo(Class<?> clazz) {
        super();
        this.clazz = clazz.getName();
        this.serialVersionUID = fetchSerialVerionUID(clazz);
    }

    /**
     * @return the clazz
     */
    public String getClazz() {
        return this.clazz;
    }

    /**
     * @return the serialVersionUID
     */
    public long getSerialVersionUID() {
        return this.serialVersionUID;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        
        return this.clazz + "/0x" + Long.toHexString(this.serialVersionUID);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.clazz == null) ? 0 : this.clazz.hashCode());
        result = prime * result
                + (int) (this.serialVersionUID ^ (this.serialVersionUID >>> 32));
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ClassInfo other = (ClassInfo) obj;
        if (this.clazz == null) {
            if (other.clazz != null)
                return false;
        } else if (!this.clazz.equals(other.clazz))
            return false;
        if (this.serialVersionUID != other.serialVersionUID)
            return false;
        return true;
    }
}
