/***********************************************************
 * $Id: ClassNameFieldMarshaler.java 124 2009-08-23 10:41:03Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.io.IOException;

import org.clazzes.remoting.FlatRemoteException;


/**
 * This field marshaler redirects the class name of an object to a string field.
 * It is mainly used in order to redirect unknown exception to a {@link FlatRemoteException}
 * returning the name of the exception class in {@link FlatRemoteException#getOriginalClassName()}.
 * 
 * @author wglas
 */
class ClassNameFieldMarshaler extends FieldMarshaler {

    public ClassNameFieldMarshaler() {
        super();
    }

    /* (non-Javadoc)
     * @see org.clazzes.remoting.marshal.impl.FieldMarshaler#readField(java.io.DataInputStream, org.clazzes.remoting.marshal.impl.MarshalerContext, java.lang.Object)
     */
    @Override
    public void readField(final CompactMarshaler context, final Object obj) throws IllegalArgumentException, IllegalAccessException, IOException {
        
        int tag = super.readTag(context);
        
        if (STRING_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading class name field ["+this.field.getName()+"]"); 
        
        this.field.set(obj,context.getDataInputStream().readUTF());
    }

    /* (non-Javadoc)
     * @see org.clazzes.remoting.marshal.impl.FieldMarshaler#writeField(java.io.DataOutputStream, org.clazzes.remoting.marshal.impl.MarshalerContext, java.lang.Object)
     */
    @Override
    public void writeField(final CompactMarshaler context, final Object obj) throws IOException, IllegalArgumentException, IllegalAccessException {
        
        context.getDataOutputStream().write(STRING_STREAM_ID);
        context.getDataOutputStream().writeUTF(obj.getClass().getName());
    }

}
