/***********************************************************
 * $Id: GregorianCalendarObjectMarshaler.java 150 2009-10-12 18:52:25Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.io.IOException;
import java.lang.reflect.Method;
import java.util.GregorianCalendar;
import java.util.TimeZone;


/**
 * This marshaler reads/writes the timestamp and timezone of a
 * {@link GregorianCalendar} instance.
 */
public class GregorianCalendarObjectMarshaler implements ObjectMarshaler {

    public GregorianCalendarObjectMarshaler() {
        super();
    }

    public Object readObject(CompactMarshaler context, long ref, ClassInfo ci)
            throws IllegalArgumentException, IllegalAccessException,
            IOException, ClassNotFoundException {
        
        
        int tag = FieldMarshaler.readTag(context);
        
        if (FieldMarshaler.INT_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading java.util.GregorianCalender firstDayInWeek."); 
       
        int firstDayInWeek = context.getDataInputStream().readInt();
        
        tag = FieldMarshaler.readTag(context);
        
        if (FieldMarshaler.LONG_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading java.util.GregorianCalender millis."); 
        
        long millis = context.getDataInputStream().readLong();
        
        tag = FieldMarshaler.readTag(context);
        
        if (FieldMarshaler.INT_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading java.util.GregorianCalender minimalDaysInFirstWeek."); 
       
        int minimalDaysInFirstWeek = context.getDataInputStream().readInt();
        
        tag = FieldMarshaler.readTag(context);
        
        if (FieldMarshaler.STRING_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading java.util.GregorianCalender timezone."); 
       
        String tzId = context.getDataInputStream().readUTF();
        
        GregorianCalendar c = new GregorianCalendar(TimeZone.getTimeZone(tzId));
        
        c.setTimeInMillis(millis);
        c.setFirstDayOfWeek(firstDayInWeek);
        c.setMinimalDaysInFirstWeek(minimalDaysInFirstWeek);

        context.cacheReadPremature(ref,c);
        
        return c;
    }

    public void writeObject(CompactMarshaler context, Object obj)
            throws IllegalArgumentException, IOException,
            IllegalAccessException, ClassNotFoundException {
        
        GregorianCalendar c = (GregorianCalendar)obj;
        
        context.getDataOutputStream().write(FieldMarshaler.INT_STREAM_ID);
        context.getDataOutputStream().writeInt(c.getFirstDayOfWeek());
        context.getDataOutputStream().write(FieldMarshaler.LONG_STREAM_ID);
        context.getDataOutputStream().writeLong(c.getTimeInMillis());
        context.getDataOutputStream().write(FieldMarshaler.INT_STREAM_ID);
        context.getDataOutputStream().writeInt(c.getMinimalDaysInFirstWeek());
        context.getDataOutputStream().write(FieldMarshaler.STRING_STREAM_ID);
        context.getDataOutputStream().writeUTF(c.getTimeZone().getID());
    }

    public Method getReadResolveMethod() {
        return null;
    }

    public Method getWriteReplaceMethod() {
        return null;
    }
}
