/***********************************************************
 * $Id: SqlDateObjectMarshaler.java 150 2009-10-12 18:52:25Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.io.IOException;
import java.lang.reflect.Method;
import java.sql.Date;


/**
 * This field marshaler reads/writes the timestamp of a {@link Date} instance.
 */
public class SqlDateObjectMarshaler implements ObjectMarshaler {

    public SqlDateObjectMarshaler() {
        super();
    }
    
    public Object readObject(CompactMarshaler context, long ref, ClassInfo ci)
            throws IllegalArgumentException, IllegalAccessException,
            IOException, ClassNotFoundException {
        
       int tag = FieldMarshaler.readTag(context);
        
       if (FieldMarshaler.LONG_STREAM_ID != tag)
           throw new IllegalArgumentException("Invalid tag ["+tag+
                                              "] found when reading java.util.Date millis");
       
       Date d = new Date(context.getDataInputStream().readLong());
       context.cacheReadPremature(ref,d);
       
       return d;
    }

    public void writeObject(CompactMarshaler context, Object obj)
            throws IllegalArgumentException, IOException,
            IllegalAccessException, ClassNotFoundException {
        
        Date date = (Date) obj;
        
        context.getDataOutputStream().write(FieldMarshaler.LONG_STREAM_ID);
        context.getDataOutputStream().writeLong(date.getTime());
    }

    public Method getReadResolveMethod() {
        return null;
    }

    public Method getWriteReplaceMethod() {
        return null;
    }

}
