/***********************************************************
 * $Id: ServerParameters.java 37 2008-10-24 20:12:45Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 24.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting.server;

import java.net.ServerSocket;

import javax.net.ServerSocketFactory;

import org.clazzes.remoting.SocketParameters;

/**
 * Configuration parameters for sockets.
 * 
 * @author wglas
 */
public class ServerParameters extends SocketParameters {

    protected ServerSocketFactory serverSocketFactory;
    private int backlog;

    /**
     * Create a ServerParameters instance with the following default values:
     * <table>
     *   <tr><td>tcpNoDelay</td><td>true</td></tr>
     *   <tr><td>backlog</td><td>4</td></tr>
     * </table>
     */
    public ServerParameters() {
        super();
        this.backlog = 4;
    }

    /**
     * Tune a server socket before actually listening to it.
     * This may involve setting some SSL-specific parameters in subclasses.
     * 
     * @param serverSocket The server socket to be parameterized.
     */
    public void tuneServerSocket(ServerSocket serverSocket) {
    }
    
    /**
     * @return The listen backlog parameter to use.
     */
    public int getBacklog() {
        return this.backlog;
    }

    /**
     * @param backlog The listen backlog parameter to set.
     */
    public void setBacklog(int backlog) {
        this.backlog = backlog;
    }
    
    /**
     * @return The socket factory used by this client. If not set by
     *    {@link #setServerSocketFactory(ServerSocketFactory)}, {@link ServerSocketFactory#getDefault()}
     *    is returned.
     */
    public ServerSocketFactory getServerSocketFactory() {
        
        if (this.serverSocketFactory == null)
            this.serverSocketFactory = ServerSocketFactory.getDefault();
        
        return this.serverSocketFactory;
    }
    
    /**
     * @param serverSocketFactory A custom server socket factory to set.
     */
    public void setServerSocketFactory(ServerSocketFactory serverSocketFactory) {
        
        this.serverSocketFactory = serverSocketFactory;
    }
   
}
